"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.performFileCheck = void 0;
const url_1 = __importDefault(require("url"));
const path_1 = __importDefault(require("path"));
const fs_1 = require("../util/fs");
async function performFileCheck(checkConfiguration, targetDirectory) {
    const results = [];
    const matchingFiles = await fs_1.expandGlobs(targetDirectory, checkConfiguration.patterns);
    for (const file of matchingFiles) {
        // Fallback to the basename for files without an extension (e.g. makefiles)
        const extension = path_1.default.extname(file.path).slice(1) || path_1.default.basename(file.path);
        const result = {
            type: extension.toLowerCase(),
            url: url_1.default.pathToFileURL(file.path).toString(),
            relativePath: file.relativePath,
        };
        if (fs_1.isTextFile(result.type)) {
            await fs_1.readStringAndCache(file.path, file.relativePath, targetDirectory);
        }
        results.push(result);
    }
    return {
        config: checkConfiguration,
        status: results.length > 0 ? 'passed' : 'failed',
        results,
        error: results.length > 0 ? undefined : 'No matching files found',
    };
}
exports.performFileCheck = performFileCheck;
