"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateReportsIndex = exports.copySupportingFiles = exports.createReport = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const filenamify_1 = __importDefault(require("filenamify"));
const fs_2 = require("../util/fs");
const viewerDistDirectory = path_1.default.join(__dirname, '..', '..', 'viewer', 'dist');
const reportTemplatePath = path_1.default.join(viewerDistDirectory, 'index.html');
async function createReport(result, resultsDirectory, fileNamePrepend = '') {
    const template = await getTemplate(reportTemplatePath);
    const report = template
        .replace('$TITLE', result.title)
        .replace('$REPORT', JSON.stringify(result));
    const reportFilePath = path_1.default.join(resultsDirectory, filenamify_1.default(fileNamePrepend + result.title.trim(), { replacement: '_' }) + '.html');
    await fs_2.writeString(reportFilePath, report);
    return reportFilePath;
}
exports.createReport = createReport;
async function copySupportingFiles(resultsDirectory) {
    return fs_2.copyDirectory(viewerDistDirectory, resultsDirectory, {
        filter(stat, filepath) {
            // Don't copy .html files
            if (stat === 'file' && path_1.default.extname(filepath) === '.html') {
                return false;
            }
            return true;
        },
    });
}
exports.copySupportingFiles = copySupportingFiles;
const indexTemplatePath = path_1.default.join(__dirname, 'index-template.html');
async function generateReportsIndex(resultsDirectory, reportTitle = 'Autocheck Reports') {
    const files = fs_1.default
        .readdirSync(resultsDirectory)
        .filter((name) => name.endsWith('.html') && name !== 'index.html')
        .map((name) => {
        const reportPath = path_1.default.join(resultsDirectory, name);
        return {
            name: name.replace('.html', ''),
            path: reportPath,
            url: name,
        };
    });
    const links = files.map((file) => {
        return `<a href="${file.url}" target="viewer">${file.name}</a>`;
    });
    const template = await getTemplate(indexTemplatePath);
    const html = template
        .replace('{{ $TITLE }}', reportTitle)
        .replace('{{ $REPORT_LINKS }}', links.join('\n'));
    const fileName = path_1.default.join(resultsDirectory, 'index.html');
    await fs_2.writeString(fileName, html);
    return fileName;
}
exports.generateReportsIndex = generateReportsIndex;
const reportFilesNamespace = '__autocheck-report-templates';
async function getTemplate(filePath) {
    const parsed = path_1.default.parse(filePath);
    try {
        return await fs_2.readStringAndCache(filePath, parsed.base, reportFilesNamespace);
    }
    catch (err) {
        console.error(`unable to read template file: ${filePath}`, err);
        return '';
    }
}
