"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.escapeForRegex = exports.parseJsRegex = exports.makeSingleDelimiterRegex = exports.makeMatchedDelimiterRegex = exports.patternToRegex = void 0;
function patternToRegex(pattern, options) {
    try {
        return options.isRegex
            ? parseJsRegex(pattern)
            : new RegExp(escapeForRegex(pattern), options.matchCase ? 'g' : 'gi'); // always global
    }
    catch {
        return null;
    }
}
exports.patternToRegex = patternToRegex;
function makeMatchedDelimiterRegex(startToken, endToken) {
    return new RegExp(escapeForRegex(startToken) + '[\\S\\s]*?' + escapeForRegex(endToken), // https://regexr.com/53766
    'g');
}
exports.makeMatchedDelimiterRegex = makeMatchedDelimiterRegex;
function makeSingleDelimiterRegex(delimiter) {
    return new RegExp(escapeForRegex(delimiter) + '.*?[\\r\\n]+', 'g'); // https://regexr.com/53771
}
exports.makeSingleDelimiterRegex = makeSingleDelimiterRegex;
// https://stackoverflow.com/a/55258958/5800506
function parseJsRegex(string) {
    string = string.trim().startsWith('/') ? string : `/${string}/i`;
    let match = string.match(/\/(.+)\/.*/);
    if (match === null) {
        throw new Error('unable to parse regex pattern: ' + string);
    }
    const pattern = match[1];
    match = string.match(/\/.+\/(.*)/);
    if (match === null) {
        throw new Error('unable to parse regex pattern: ' + string);
    }
    const flags = match[1];
    return new RegExp(pattern, flags.includes('g') ? flags : flags + 'g'); // always global
}
exports.parseJsRegex = parseJsRegex;
function escapeForRegex(string) {
    return string.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
}
exports.escapeForRegex = escapeForRegex;
